@@ -149,10 +149,10 @@ attachments region.
 	  (goto-char (1- (mew-attach-begin)))
 	  (re-search-forward "^..... " nil t)
 	  (mew-attach-move-onto-file))
-      (setq numreg (int-to-string (car nums)))
+      (setq numreg (number-to-string (car nums)))
       (setq nums (cdr nums))
       (while nums
-	(setq numreg (concat (int-to-string (car nums)) "." numreg))
+	(setq numreg (concat (number-to-string (car nums)) "." numreg))
 	(setq nums (cdr nums)))
       (setq numreg (regexp-quote numreg))
       (goto-char (1+ (mew-attach-begin)))
@@ -746,7 +746,7 @@ Input decryptors' addresses."
       nil)))
 
 (defun mew-draft-dnd-handle-local-file (uri action)
-  (let* ((from (x-dnd-get-local-file-name uri t))
+  (let* ((from (dnd-get-local-file-name uri t))
 	 (to (file-name-nondirectory from)))
     (when from
       (unless (mew-attach-p)
@@ -767,8 +767,9 @@ Input decryptors' addresses."
 	(message "Nothing happened"))))))
 
 (defun mew-draft-dnd-handle-file (uri action)
-  (let ((local-file (x-dnd-get-local-file-uri uri)))
-    (if local-file (mew-draft-dnd-handle-local-file local-file action)
+  (let ((local-file (dnd-get-local-file-uri uri)))
+    (if local-file
+	(mew-draft-dnd-handle-local-file local-file action)
       nil)))
 
 (provide 'mew-attach)
